@@ -81,13 +81,13 @@ class ColorDetectionConfig(BaseConfig):
     smoothing_window_size: int = 20
     smoothing_cooldown_frames: int = 5
     smoothing_confidence_range_factor: float = 0.5
-    zone_config: Optional[Dict[str, List[List[float]]]] = field(
-    default_factory=lambda: {
-        "zones": {
-            "Entrance": [[148, 474], [1207, 486], [1914, 882], [1910, 1070], [151, 1075]],
-        }
-    }
-)
+    zone_config: Optional[Dict[str, List[List[float]]]] = None #field(
+#     default_factory=lambda: {
+#         "zones": {
+#             "Entrance": [[148, 474], [1207, 486], [1914, 882], [1910, 1070], [151, 1075]],
+#         }
+#     }
+# )
 
     def validate(self) -> List[str]:
         errors = super().validate()
